==> kadu_3.0~rc1.orig.tar.bz2: kadu-3.0-rc1/plugins/sql_history/translations/sql_history_pl.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="pl">
<context>
    <name>HistorySqlStorage</name>
    <message>
        <source>Preparing history database...</source>
        <translation>Przygotowywanie histori bazy danych...</translation>
    </message>
    <message>
        <source>History</source>
        <translation>Historia</translation>
    </message>
    <message>
        <source>Opening database failed. Error message:
%1</source>
        <translation>Otwieranie bazy danych zakończone niepowodzeniem. Numer błędu:
%1</translation>
    </message>
    <message>
        <source>Kadu</source>
        <translation>Kadu</translation>
    </message>
    <message>
        <source>It seems your Qt library does not provide support for selected database. Please install Qt with %1 plugin.</source>
        <translation>Twoja biblioteka Qt nie wspiera wybranej bazy danych. Zainstaluj Qt z wtyczką %1.</translation>
    </message>
</context>
<context>
    <name>SqlInitializer</name>
    <message>
        <source>Copying history file to new location: %1 ...</source>
        <translation>Kopiowanie plików zawierających historię rozmów do nowej lokalizacji: %1 ...</translation>
    </message>
    <message>
        <source>Unable to copy history file to new location. Check if disk is full.</source>
        <translation>Kopiowanie plików historii do nowej lokalizacji nie może zostać wykonane. Sprawdź, czy na dysku jest odpowiednia ilość wolnego miejsca.</translation>
    </message>
    <message>
        <source>Unable to open database: %1</source>
        <translation>Nie można otworzyć bazy danych: %1</translation>
    </message>
    <message>
        <source>History file is corrupted, performing recovery...</source>
        <translation>Pliki historii są uszkodzone, trwa odzyskiwanie...</translation>
    </message>
    <message>
        <source>Recovery completed.</source>
        <translation>Odzyskiwanie zakończone sukcesem.</translation>
    </message>
    <message>
        <source>Recovery failed: %s</source>
        <translation>Odzyskiwanie zakończone niepowodzeniem: %s</translation>
    </message>
    <message>
        <source>History file is outdated, performing import...</source>
        <translation>Pliki historii są przestarzałe, zaimportuj nowe...</translation>
    </message>
    <message>
        <source>Import completed.</source>
        <translation>Zakończono import.</translation>
    </message>
    <message>
        <source>Copying completed.</source>
        <translation>Zakończono kopiowanie.</translation>
    </message>
</context>
<context>
    <name>SqlRestore</name>
    <message>
        <source>No error.</source>
        <translation>Brak błędów.</translation>
    </message>
    <message>
        <source>sqlite3 executable not found.</source>
        <translation>Nie znaleziono sqlite3.exe</translation>
    </message>
    <message>
        <source>Invalid invocation of recovery script.</source>
        <translation>Nieprawidłowe wywołanie skryptu odzyskiwania.</translation>
    </message>
    <message>
        <source>Unable to read corrupted database.</source>
        <translation>Nie można przeglądać uszkodzonej bazy danych.</translation>
    </message>
    <message>
        <source>Unable to create backup file. Disc may be full.</source>
        <translation>Nie można wykonać backup&apos;u. Dysk może być pełny.</translation>
    </message>
    <message>
        <source>Recovery script not found or not executable.</source>
        <translation>Nie znaleziono skryptu odzyskiwania lub nie może on zostać uruchomiony.</translation>
    </message>
    <message>
        <source>Unknown error during database recovery.</source>
        <translation>Nieznany błąd podczas przywracania baza.</translation>
    </message>
</context>
</TS>

==> kadu_4.1.orig.tar.bz2: kadu-4.1/plugins/sql_history/translations/sql_history_pl.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS language="pl" version="2.1">
<context>
    <name>HistorySqlStorage</name>
    <message>
        <source>Preparing history database...</source>
        <translation>Przygotowywanie histori bazy danych...</translation>
    </message>
    <message>
        <source>History</source>
        <translation>Historia</translation>
    </message>
    <message>
        <source>Opening database failed. Error message:
%1</source>
        <translation>Otwieranie bazy danych zakończone niepowodzeniem. Numer błędu:
%1</translation>
    </message>
    <message>
        <source>Kadu</source>
        <translation>Kadu</translation>
    </message>
    <message>
        <source>It seems your Qt library does not provide support for selected database. Please install Qt with %1 plugin.</source>
        <translation>Twoja biblioteka Qt nie wspiera wybranej bazy danych. Zainstaluj Qt z wtyczką %1.</translation>
    </message>
</context>
<context>
    <name>SqlInitializer</name>
    <message>
        <source>Copying history file to new location: %1 ...</source>
        <translation>Kopiowanie plików zawierających historię rozmów do nowej lokalizacji: %1 ...</translation>
    </message>
    <message>
        <source>Unable to copy history file to new location. Check if disk is full.</source>
        <translation>Kopiowanie plików historii do nowej lokalizacji nie może zostać wykonane. Sprawdź, czy na dysku jest odpowiednia ilość wolnego miejsca.</translation>
    </message>
    <message>
        <source>Unable to open database: %1</source>
        <translation>Nie można otworzyć bazy danych: %1</translation>
    </message>
    <message>
        <source>History file is corrupted, performing recovery...</source>
        <translation>Pliki historii są uszkodzone, trwa odzyskiwanie...</translation>
    </message>
    <message>
        <source>Recovery completed.</source>
        <translation>Odzyskiwanie zakończone sukcesem.</translation>
    </message>
    <message>
        <source>Recovery failed: %s</source>
        <translation>Odzyskiwanie zakończone niepowodzeniem: %s</translation>
    </message>
    <message>
        <source>History file is outdated, performing import...</source>
        <translation>Pliki historii są przestarzałe, zaimportuj nowe...</translation>
    </message>
    <message>
        <source>Import completed.</source>
        <translation>Zakończono import.</translation>
    </message>
    <message>
        <source>Copying completed.</source>
        <translation>Zakończono kopiowanie.</translation>
    </message>
</context>
<context>
    <name>SqlRestore</name>
    <message>
        <source>No error.</source>
        <translation>Brak błędów.</translation>
    </message>
    <message>
        <source>sqlite3 executable not found.</source>
        <translation>Nie znaleziono sqlite3.exe</translation>
    </message>
    <message>
        <source>Invalid invocation of recovery script.</source>
        <translation>Nieprawidłowe wywołanie skryptu odzyskiwania.</translation>
    </message>
    <message>
        <source>Unable to read corrupted database.</source>
        <translation>Nie można przeglądać uszkodzonej bazy danych.</translation>
    </message>
    <message>
        <source>Unable to create backup file. Disc may be full.</source>
        <translation>Nie można wykonać backup&apos;u. Dysk może być pełny.</translation>
    </message>
    <message>
        <source>Recovery script not found or not executable.</source>
        <translation>Nie znaleziono skryptu odzyskiwania lub nie może on zostać uruchomiony.</translation>
    </message>
    <message>
        <source>Unknown error during database recovery.</source>
        <translation>Nieznany błąd podczas przywracania baza.</translation>
    </message>
</context>
</TS>
